==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var PolarAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeries, _super);
    function PolarAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarAreaSeries.$;
        return _this;
    }
    PolarAreaSeries.prototype.get_d8 = function () {
        return true;
    };
    PolarAreaSeries.prototype.cg = function () {
        return new PolarAreaSeriesView(this);
    };
    PolarAreaSeries.prototype.wr = function () {
        return false;
    };
    PolarAreaSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.zm = a;
    };
    PolarAreaSeries.prototype.zk = function (a) {
        var b = a;
        b.c8();
    };
    PolarAreaSeries.prototype.zl = function (a, b) {
        if (a.m.count > 0) {
            var c = a.m._inner[0];
            var d = a.m._inner[a.m.count - 1];
            var e = c.x == d.x && c.y == d.y;
            if (!e) {
                a.m.add(a.m._inner[0]);
            }
        }
        var f = b;
        f.c9(a.m, this.hj);
        this.v3.az(this, this.wq(), runOn(this, this.vg));
        var g = false;
        var h = this.v3.b;
        if (h != null) {
            g = true;
        }
        if (g) {
            this.x5(-1, this.wc.count, b.q);
        }
        var i = f.df;
        var j = f.de;
        this.v3.ad(i, true, false, true, true);
        this.v3.ad(j, false, true, false, false);
        j._opacity = this.v3.j * this.hf;
    };
    PolarAreaSeries.prototype.get_zh = function () {
        return true;
    };
    PolarAreaSeries.prototype.zc = function () {
        return this.zn;
    };
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:zn:zp', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
}(PolarLineSeriesBase));
export { PolarAreaSeries };
/**
 * @hidden
 */
var PolarAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeriesView, _super);
    function PolarAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c7 = null;
        _this.dd = new Path();
        _this.dc = new Path();
        _this.db = new Path();
        _this.da = new Path();
        _this.c7 = a;
        return _this;
    }
    PolarAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c7.ua = Defaults.e;
        }
    };
    Object.defineProperty(PolarAreaSeriesView.prototype, "de", {
        get: function () {
            return this.dc;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PolarAreaSeriesView.prototype, "df", {
        get: function () {
            return this.dd;
        },
        enumerable: false,
        configurable: true
    });
    PolarAreaSeriesView.prototype.c8 = function () {
        this.dc.an = null;
        this.dd.an = null;
        this.da.an = null;
        this.db.an = null;
        this.as();
    };
    PolarAreaSeriesView.prototype.c9 = function (a, b) {
        var c = new List$1(Point_$type, 1, a);
        this.c7.y9.d(this.dd, c, b);
        this.c7.y9.d(this.dc, c, b);
        this.as();
    };
    PolarAreaSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarAreaSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.db.an = this.dd.an;
        this.da.an = this.dc.an;
        this.db._stroke = a;
        this.db.ad = this.e.hk + 3;
        this.da._fill = a;
        this.da._opacity = 1;
    };
    PolarAreaSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.da);
                a.t(this.db);
            }
            else {
                a.t(this.dc);
                a.t(this.dd);
            }
        }
    };
    PolarAreaSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.a9.exportPathData(a, this.dd, "polarShape", ["Main"]);
        this.e.a9.exportPathData(a, this.dc, "fillShape", ["Fill"]);
    };
    PolarAreaSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.s6 = a;
        this.e.ir = 5;
        this.e.is = 5;
        this.e.it = 5;
    };
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
}(PolarLineSeriesBaseView));
export { PolarAreaSeriesView };

==> igniteui-angular-charts-18.2.0-beta.0.tgz: package/esm5/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var PolarAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeries, _super);
    function PolarAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarAreaSeries.$;
        return _this;
    }
    PolarAreaSeries.prototype.bj = function () {
        return new PolarAreaSeries();
    };
    PolarAreaSeries.prototype.get_eu = function () {
        return true;
    };
    PolarAreaSeries.prototype.cs = function () {
        return new PolarAreaSeriesView(this);
    };
    PolarAreaSeries.prototype.zw = function () {
        return false;
    };
    PolarAreaSeries.prototype.qz = function (a) {
        _super.prototype.qz.call(this, a);
        this.acs = a;
    };
    PolarAreaSeries.prototype.acq = function (a) {
        var b = a;
        b.da();
    };
    PolarAreaSeries.prototype.acr = function (a, b) {
        if (a.m.count > 0) {
            var c = a.m._inner[0];
            var d = a.m._inner[a.m.count - 1];
            var e = c.x == d.x && c.y == d.y;
            if (!e) {
                a.m.add(a.m._inner[0]);
            }
        }
        var f = b;
        f.db(a.m, this.id);
        this.y3.az(this, this.zv(), runOn(this, this.yl));
        var g = false;
        var h = this.y3.b;
        if (h != null) {
            g = true;
        }
        if (g) {
            this.aba(-1, this.zh.count, b.q);
        }
        var i = f.dh;
        var j = f.dg;
        this.y3.ad(i, true, false, true, true);
        this.y3.ad(j, false, true, false, false);
        j._opacity = this.y3.j * this.h9;
    };
    PolarAreaSeries.prototype.get_acn = function () {
        return true;
    };
    PolarAreaSeries.prototype.aci = function () {
        return this.act;
    };
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:act:acv', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
}(PolarLineSeriesBase));
export { PolarAreaSeries };
/**
 * @hidden
 */
var PolarAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeriesView, _super);
    function PolarAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.df = new Path();
        _this.de = new Path();
        _this.dd = new Path();
        _this.dc = new Path();
        _this.c9 = a;
        return _this;
    }
    PolarAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c9.w8 = Defaults.e;
        }
    };
    Object.defineProperty(PolarAreaSeriesView.prototype, "dg", {
        get: function () {
            return this.de;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PolarAreaSeriesView.prototype, "dh", {
        get: function () {
            return this.df;
        },
        enumerable: false,
        configurable: true
    });
    PolarAreaSeriesView.prototype.da = function () {
        this.de.an = null;
        this.df.an = null;
        this.dc.an = null;
        this.dd.an = null;
        this.as();
    };
    PolarAreaSeriesView.prototype.db = function (a, b) {
        var c = new List$1(Point_$type, 1, a);
        this.c9.acf.d(this.df, c, b);
        this.c9.acf.d(this.de, c, b);
        this.as();
    };
    PolarAreaSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarAreaSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.dd.an = this.df.an;
        this.dc.an = this.de.an;
        this.dd._stroke = a;
        this.dd.ad = this.e.ie + 3;
        this.dc._fill = a;
        this.dc._opacity = 1;
    };
    PolarAreaSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.dc);
                a.t(this.dd);
            }
            else {
                a.t(this.de);
                a.t(this.df);
            }
        }
    };
    PolarAreaSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bc.exportPathData(a, this.df, "polarShape", ["Main"]);
        this.e.bc.exportPathData(a, this.de, "fillShape", ["Fill"]);
    };
    PolarAreaSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.vz = a;
        this.e.jm = 5;
        this.e.jn = 5;
        this.e.jo = 5;
    };
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
}(PolarLineSeriesBaseView));
export { PolarAreaSeriesView };
